<!DOCTYPE kpartgui>
<kpartgui name="kopete" version="15">
	<MenuBar>
		<Menu name="file" noMerge="1">
			<text>&amp;File</text>
			<Action name="Connection"/>
			<Action name="Status"/>
			<Separator lineSeparator="true"/>
			<Action name="AddContact"/>
			<Action name="AddGroup"/>
			<Separator lineSeparator="true"/>
			<Action name="file_quit"/>
		</Menu>
		<Menu name="edit">
			<text>&amp;Edit</text>
			<Action name="contactSendMessage" />
			<Action name="contactStartChat" />
			<Action name="contactSendFile" />
			<Separator lineSeparator="true" />
			<Action name="contactMove" />
			<Action name="contactCopy" />
			<Action name="contactRemoveFromGroup" />
			<Action name="contactRemove" />
			<Action name="contactRename" />
			<Action name="contactAddContact" />
			<Action name="contactAddTemporaryContact" />
			<Separator lineSeparator="true" />
			<Merge />
			<Separator lineSeparator="true" />
			<Action name="contactProperties" />

		</Menu>
		<Menu name="settings">
			<text>&amp;Settings</text>
			<Action name="settings_showmenubar" />
			<Merge name="StandardToolBarMenuHandler" />
			<Action name="settings_showstatusbar" />
			<Separator lineSeparator="true" />
			<Action name="settings_show_offliners" />
			<Action name="settings_show_empty_groups" />
			<Separator lineSeparator="true" />
			<Action name="settings_keys" />
			<Action name="settings_global" />
			<Action name="settings_notifications" />
			<Action name="settings_toolbars" />
			<Action name="settings_plugins"/>
			<Action name="settings_prefs" />
		</Menu>
	</MenuBar>

	<ToolBar fullWidth="true" name="mainToolBar">
		<Action name="ConnectAll"/>
		<Action name="DisconnectAll"/>
		<Action name="Status"/>
		<Action name="AddContact"/>
		<Action name="settings_show_offliners"/>
		<Action name="settings_show_empty_groups"/>
	</ToolBar>

	<Menu name="contact_popup">
		<Action name="contactSendMessage" />
		<Action name="contactStartChat" />
		<Action name="contactSendFile" />
		<Action name="contactSendEmail" />
		<Action name="contactSyncKABC"/>
		<Separator lineSeparator="true" />
		<Action name="contactMove" />
		<Action name="contactCopy" />
		<Action name="contactRemoveFromGroup" />
		<Action name="contactRemove" />
		<Action name="contactRename" />
		<Action name="contactAddContact" />
		<Action name="contactAddTemporaryContact" />
		<Separator lineSeparator="true" />
		<Merge />
		<Separator lineSeparator="true" />
		<Action name="contactProperties" />
		<Separator lineSeparator="true" />
	</Menu>
	<Menu name="group_popup">
		<Action name="contactRemove" />
		<Action name="contactRename" />
		<Separator lineSeparator="true" />
		<Action name="contactProperties" />
	</Menu>
	<Menu name="contactlistitems_popup">
		<Action name="contactRemove" />
	</Menu>
	<Menu name="contactlist_popup">
		<Action name="AddContact"/>
		<Action name="AddGroup"/>
		<Separator lineSeparator="true"/>
		<Action name="settings_showmenubar" />
		<Action name="settings_show_offliners" />
		<Action name="settings_show_empty_groups" />
	</Menu>
</kpartgui>
